mds-project-durationcolumn
==========================
Tryton module to add a duration-column to the list of projects.

Install
=======

pip install mds-project-durationcolumn

Requires
========
- Tryton 4.6

Changes
=======

*4.6.0 - 05.10.2018*

 - init
